@@ -1,4 +1,4 @@
 from .response import ABCResponse, Response, HTMLResponse, HTMLResponseFactory
-from .handler import ABCHandler, AutoHandler
+from .handler import ABCHandler, AutoHandler, Request
 from .context import Context
 from .tools import regex_path, resolve_mobile
