@@ -1,6 +1,7 @@
 import typing
 import re
 from actor.context import MOBILE_AGENTS
+from .handler.abc import Request
 
 
 def regex_path(paths: typing.Union[str, typing.List[str]]):
@@ -8,11 +9,11 @@ def regex_path(paths: typing.Union[str, typing.List[str]]):
     patterns = [re.compile(path) for path in paths]
 
     def wrapper(func):
-        def call_wrapper(self, p: str, headers: dict, *args):
-            matches = [re.match(pattern, p) for pattern in patterns]
+        def call_wrapper(self, request: Request, *args):
+            matches = [re.match(pattern, request.path) for pattern in patterns]
             matches = list(filter(bool, matches))
             if matches:
-                return func(self, p, headers, *(matches[0].groups()), *args)
+                return func(self, request, *(matches[0].groups()), *args)
             return None
 
         return call_wrapper
@@ -21,13 +22,13 @@ def regex_path(paths: typing.Union[str, typing.List[str]]):
 
 
 def resolve_mobile(func):
-    def call_wrapper(self, p: str, headers: dict, *args, **kwargs):
+    def call_wrapper(self, request: Request, *args, **kwargs):
         mobile = any(
             [
-                agent.lower() in (headers.get(b"user-agent", b"")).decode().lower()
+                agent.lower() in (request.headers.get(b"user-agent", b"")).decode().lower()
                 for agent in MOBILE_AGENTS
             ]
         )
-        return func(self, p, headers, *args, **kwargs, mobile=mobile)
+        return func(self, request, *args, **kwargs, mobile=mobile)
 
     return call_wrapper
